package oracle.spatial.georaster.gdaltest;

import java.nio.ByteBuffer;

import org.gdal.gdal.Band;
import org.gdal.gdal.Dataset;
import org.gdal.gdal.Driver;
import org.gdal.gdal.gdal;
import org.gdal.gdalconst.gdalconstConstants;


public class GDALLoader {

	public static void main(String[] args) {

		Dataset dataset1;
		Dataset dataset2;
		
		Band band1;
		Band band2;
		
		Driver driver;
		
		gdal.AllRegister();
		
		driver = gdal.GetDriverByName("georaster");
		
		dataset1 = gdal.Open("241894.tif");
		band1 = dataset1.GetRasterBand(1);
		
		int xSize = dataset1.getRasterXSize();
		int ySize = dataset1.getRasterYSize();
		int bands = dataset1.getRasterCount();
		int dType = band1.getDataType();

		if (dType != gdalconstConstants.GDT_Byte) {
            System.err.println("Only support Byte.");
            System.exit(1);			
		}
		
		String stmt = "geor:georaster/georaster@orcl,georaster_table,georaster";
		
		String options[] = new String[]{"INSERT=VALUES(102, '241894_2.tif', SDO_GEOR.INIT('rdt_01',2))","BLOCKXSIZE=512","BLOCKYSIZE=512"};
		
		long start = System.currentTimeMillis();
		dataset2 = driver.Create(stmt, xSize, ySize, bands, dType, options);
		System.out.println(stmt);
		
		System.out.println(dataset1.GetGeoTransform()[1]);
		dataset2.SetGeoTransform(dataset1.GetGeoTransform());
		dataset2.SetProjection(dataset1.GetProjection());
		
		band2 = dataset2.GetRasterBand(1);
		
		ByteBuffer buffer = ByteBuffer.allocateDirect(xSize);
		
		for( int b = 1; b <= bands; b ++){
			System.out.printf("Load band%d\n", b);
			band1 = dataset1.GetRasterBand(b);
			band2 = dataset2.GetRasterBand(b);
		for( int i =0; i < ySize; i++ ) {
			System.out.printf("Read line:%d from band1\n", i);
			buffer = band1.ReadRaster_Direct(0,i,xSize,1);
			System.out.printf("Write line:%d to band2\n", i);
			band2.WriteRaster_Direct(0,i,xSize,1,buffer);
		}
		
		dataset2.FlushCache();
		}
		
		long duration = System.currentTimeMillis() - start;
		
		System.out.println("generate a new georaster : " + dataset2.GetDescription());
		System.out.printf("Duration:%d.\n", duration);
		
		dataset1.delete();
		dataset2.delete();		
	}

}

